pub struct ExecutionGraph {
pub name: String,
pub owner: Option<String>,
pub charter_from: Option<String>,
pub steps: Vec<GraphStep>,
pub fanout_groups: BTreeMap<String, FanoutGroupPolicy>,
pub policy: Option<GraphPolicy>,
pub raw: RawGraphIr,
}Fields
name: Stringowner: Option<String>charter_from: Option<String>The input key carrying the parent charter authority term that steps with a
mint_authority directive attenuate from. Declared once at the graph (or
runner) level, replacing per-skill re-threading of the parent authority. A
step’s mint_authority is only coherent when this is set.
steps: Vec<GraphStep>fanout_groups: BTreeMap<String, FanoutGroupPolicy>policy: Option<GraphPolicy>raw: RawGraphIrTrait Implementations
Sourceimpl Clone for ExecutionGraph
impl Clone for ExecutionGraph
Sourcefn clone(&self) -> ExecutionGraph
fn clone(&self) -> ExecutionGraph
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionGraph
impl Debug for ExecutionGraph
Sourceimpl<'de> Deserialize<'de> for ExecutionGraph
impl<'de> Deserialize<'de> for ExecutionGraph
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ExecutionGraph
impl PartialEq for ExecutionGraph
Sourcefn eq(&self, other: &ExecutionGraph) -> bool
fn eq(&self, other: &ExecutionGraph) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ExecutionGraph
impl Serialize for ExecutionGraph
impl StructuralPartialEq for ExecutionGraph