pub struct SkillSource {Show 21 fields
pub source_type: SourceKind,
pub command: Option<String>,
pub args: Vec<String>,
pub cwd: Option<String>,
pub timeout_seconds: Option<u64>,
pub input_mode: Option<InputMode>,
pub sandbox: Option<SkillSandbox>,
pub server: Option<SkillMcpServer>,
pub catalog_ref: Option<String>,
pub tool: Option<String>,
pub arguments: Option<JsonObject>,
pub agent_card_url: Option<String>,
pub agent_identity: Option<String>,
pub agent: Option<String>,
pub task: Option<String>,
pub hook: Option<String>,
pub outputs: Option<JsonObject>,
pub graph: Option<ExecutionGraph>,
pub http: Option<SkillHttpSource>,
pub act: Option<ActDeclaration>,
pub raw: JsonObject,
}Fields
source_type: SourceKindcommand: Option<String>args: Vec<String>cwd: Option<String>timeout_seconds: Option<u64>input_mode: Option<InputMode>sandbox: Option<SkillSandbox>server: Option<SkillMcpServer>catalog_ref: Option<String>tool: Option<String>arguments: Option<JsonObject>agent_card_url: Option<String>agent_identity: Option<String>agent: Option<String>task: Option<String>hook: Option<String>outputs: Option<JsonObject>graph: Option<ExecutionGraph>http: Option<SkillHttpSource>act: Option<ActDeclaration>The declared act this source performs, validated at load. None when no
act: block is declared (the run then seals a generic observation act).
raw: JsonObjectTrait Implementations
Sourceimpl Clone for SkillSource
impl Clone for SkillSource
Sourcefn clone(&self) -> SkillSource
fn clone(&self) -> SkillSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SkillSource
impl Debug for SkillSource
Sourceimpl<'de> Deserialize<'de> for SkillSource
impl<'de> Deserialize<'de> for SkillSource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SkillSource
impl PartialEq for SkillSource
Sourcefn eq(&self, other: &SkillSource) -> bool
fn eq(&self, other: &SkillSource) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SkillSource
impl Serialize for SkillSource
impl StructuralPartialEq for SkillSource